@@ -9,9 +9,10 @@ use reqwest::{
 use sodiumoxide::crypto::secretbox;
 
 use atuin_common::api::{
-    AddHistoryRequest, CountResponse, LoginRequest, LoginResponse, RegisterResponse,
-    SyncHistoryResponse,
+    AddHistoryRequest, CountResponse, ErrorResponse, IndexResponse, LoginRequest, LoginResponse,
+    RegisterResponse, SyncHistoryResponse,
 };
+use semver::Version;
 
 use crate::{
     encryption::{decode_key, decrypt},
@@ -58,7 +59,8 @@ pub async fn register(
         .await?;
 
     if !resp.status().is_success() {
-        bail!("failed to register user");
+        let error = resp.json::<ErrorResponse>().await?;
+        bail!("failed to register user: {}", error.reason);
     }
 
     let session = resp.json::<RegisterResponse>().await?;
@@ -77,13 +79,35 @@ pub async fn login(address: &str, req: LoginRequest) -> Result<LoginResponse> {
         .await?;
 
     if resp.status() != reqwest::StatusCode::OK {
-        bail!("invalid login details");
+        let error = resp.json::<ErrorResponse>().await?;
+        bail!("invalid login details: {}", error.reason);
     }
 
     let session = resp.json::<LoginResponse>().await?;
     Ok(session)
 }
 
+pub async fn latest_version() -> Result<Version> {
+    let url = "https://api.atuin.sh";
+    let client = reqwest::Client::new();
+
+    let resp = client
+        .get(url)
+        .header(USER_AGENT, APP_USER_AGENT)
+        .send()
+        .await?;
+
+    if resp.status() != reqwest::StatusCode::OK {
+        let error = resp.json::<ErrorResponse>().await?;
+        bail!("failed to check latest version: {}", error.reason);
+    }
+
+    let index = resp.json::<IndexResponse>().await?;
+    let version = Version::parse(index.version.as_str())?;
+
+    Ok(version)
+}
+
 impl<'a> Client<'a> {
     pub fn new(sync_addr: &'a str, session_token: &'a str, key: String) -> Result<Self> {
         let mut headers = HeaderMap::new();
