@@ -8,9 +8,13 @@ use config::{Config, Environment, File as ConfigFile, FileFormat};
 use eyre::{eyre, Context, Result};
 use fs_err::{create_dir_all, File};
 use parse_duration::parse;
+use semver::Version;
 use serde::Deserialize;
 
 pub const HISTORY_PAGE_SIZE: i64 = 100;
+pub const LAST_SYNC_FILENAME: &str = "last_sync_time";
+pub const LAST_VERSION_CHECK_FILENAME: &str = "last_version_check_time";
+pub const LATEST_VERSION_FILENAME: &str = "latest_version";
 
 #[derive(Clone, Debug, Deserialize, Copy)]
 pub enum SearchMode {
@@ -50,7 +54,17 @@ impl FilterMode {
     }
 }
 
+#[derive(Clone, Debug, Deserialize, Copy)]
+pub enum ExitMode {
+    #[serde(rename = "return-original")]
+    ReturnOriginal,
+
+    #[serde(rename = "return-query")]
+    ReturnQuery,
+}
+
 // FIXME: Can use upstream Dialect enum if https://github.com/stevedonovan/chrono-english/pull/16 is merged
+// FIXME: Above PR was merged, but dependency was changed to interim (fork of chrono-english) in the ... interim
 #[derive(Clone, Debug, Deserialize, Copy)]
 pub enum Dialect {
     #[serde(rename = "us")]
@@ -60,11 +74,11 @@ pub enum Dialect {
     Uk,
 }
 
-impl From<Dialect> for chrono_english::Dialect {
-    fn from(d: Dialect) -> chrono_english::Dialect {
+impl From<Dialect> for interim::Dialect {
+    fn from(d: Dialect) -> interim::Dialect {
         match d {
-            Dialect::Uk => chrono_english::Dialect::Uk,
-            Dialect::Us => chrono_english::Dialect::Us,
+            Dialect::Uk => interim::Dialect::Uk,
+            Dialect::Us => interim::Dialect::Us,
         }
     }
 }
@@ -86,6 +100,7 @@ pub struct Settings {
     pub dialect: Dialect,
     pub style: Style,
     pub auto_sync: bool,
+    pub update_check: bool,
     pub sync_address: String,
     pub sync_frequency: String,
     pub db_path: String,
@@ -93,37 +108,72 @@ pub struct Settings {
     pub session_path: String,
     pub search_mode: SearchMode,
     pub filter_mode: FilterMode,
+    pub exit_mode: ExitMode,
     // This is automatically loaded when settings is created. Do not set in
     // config! Keep secrets and settings apart.
     pub session_token: String,
 }
 
 impl Settings {
-    pub fn save_sync_time() -> Result<()> {
+    fn save_to_data_dir(filename: &str, value: &str) -> Result<()> {
         let data_dir = atuin_common::utils::data_dir();
         let data_dir = data_dir.as_path();
 
-        let sync_time_path = data_dir.join("last_sync_time");
+        let path = data_dir.join(filename);
 
-        fs_err::write(sync_time_path, Utc::now().to_rfc3339())?;
+        fs_err::write(path, value)?;
 
         Ok(())
     }
 
-    pub fn last_sync() -> Result<chrono::DateTime<Utc>> {
+    fn read_from_data_dir(filename: &str) -> Option<String> {
         let data_dir = atuin_common::utils::data_dir();
         let data_dir = data_dir.as_path();
 
-        let sync_time_path = data_dir.join("last_sync_time");
+        let path = data_dir.join(filename);
 
-        if !sync_time_path.exists() {
-            return Ok(Utc.ymd(1970, 1, 1).and_hms(0, 0, 0));
+        if !path.exists() {
+            return None;
         }
 
-        let time = fs_err::read_to_string(sync_time_path)?;
-        let time = chrono::DateTime::parse_from_rfc3339(time.as_str())?;
+        let value = fs_err::read_to_string(path);
 
-        Ok(time.with_timezone(&Utc))
+        value.ok()
+    }
+
+    fn save_current_time(filename: &str) -> Result<()> {
+        Settings::save_to_data_dir(filename, Utc::now().to_rfc3339().as_str())?;
+
+        Ok(())
+    }
+
+    fn load_time_from_file(filename: &str) -> Result<chrono::DateTime<Utc>> {
+        let value = Settings::read_from_data_dir(filename);
+
+        match value {
+            Some(v) => {
+                let time = chrono::DateTime::parse_from_rfc3339(v.as_str())?;
+
+                Ok(time.with_timezone(&Utc))
+            }
+            None => Ok(Utc.ymd(1970, 1, 1).and_hms(0, 0, 0)),
+        }
+    }
+
+    pub fn save_sync_time() -> Result<()> {
+        Settings::save_current_time(LAST_SYNC_FILENAME)
+    }
+
+    pub fn save_version_check_time() -> Result<()> {
+        Settings::save_current_time(LAST_VERSION_CHECK_FILENAME)
+    }
+
+    pub fn last_sync() -> Result<chrono::DateTime<Utc>> {
+        Settings::load_time_from_file(LAST_SYNC_FILENAME)
+    }
+
+    pub fn last_version_check() -> Result<chrono::DateTime<Utc>> {
+        Settings::load_time_from_file(LAST_VERSION_CHECK_FILENAME)
     }
 
     pub fn should_sync(&self) -> Result<bool> {
@@ -142,6 +192,67 @@ impl Settings {
         }
     }
 
+    fn needs_update_check(&self) -> Result<bool> {
+        let last_check = Settings::last_version_check()?;
+        let diff = Utc::now() - last_check;
+
+        // Check a max of once per hour
+        Ok(diff.num_hours() >= 1)
+    }
+
+    async fn latest_version(&self) -> Result<Version> {
+        // Default to the current version, and if that doesn't parse, a version so high it's unlikely to ever
+        // suggest upgrading.
+        let current =
+            Version::parse(env!("CARGO_PKG_VERSION")).unwrap_or(Version::new(100000, 0, 0));
+
+        if !self.needs_update_check()? {
+            // Worst case, we don't want Atuin to fail to start because something funky is going on with
+            // version checking.
+            let version = match Settings::read_from_data_dir(LATEST_VERSION_FILENAME) {
+                Some(v) => Version::parse(&v).unwrap_or(current),
+                None => current,
+            };
+
+            return Ok(version);
+        }
+
+        #[cfg(feature = "sync")]
+        let latest = crate::api_client::latest_version().await.unwrap_or(current);
+
+        #[cfg(not(feature = "sync"))]
+        let latest = current;
+
+        Settings::save_version_check_time()?;
+        Settings::save_to_data_dir(LATEST_VERSION_FILENAME, latest.to_string().as_str())?;
+
+        Ok(latest)
+    }
+
+    // Return Some(latest version) if an update is needed. Otherwise, none.
+    pub async fn needs_update(&self) -> Option<Version> {
+        if !self.update_check {
+            return None;
+        }
+
+        let current =
+            Version::parse(env!("CARGO_PKG_VERSION")).unwrap_or(Version::new(100000, 0, 0));
+
+        let latest = self.latest_version().await;
+
+        if latest.is_err() {
+            return None;
+        }
+
+        let latest = latest.unwrap();
+
+        if latest > current {
+            return Some(latest);
+        }
+
+        None
+    }
+
     pub fn new() -> Result<Self> {
         let config_dir = atuin_common::utils::config_dir();
 
@@ -172,10 +283,12 @@ impl Settings {
             .set_default("session_path", session_path.to_str())?
             .set_default("dialect", "us")?
             .set_default("auto_sync", true)?
+            .set_default("update_check", true)?
             .set_default("sync_frequency", "1h")?
             .set_default("sync_address", "https://api.atuin.sh")?
-            .set_default("search_mode", "prefix")?
+            .set_default("search_mode", "fuzzy")?
             .set_default("filter_mode", "global")?
+            .set_default("exit_mode", "return-original")?
             .set_default("session_token", "")?
             .set_default("style", "auto")?
             .add_source(
