@@ -3,7 +3,7 @@
 set -euo pipefail
 
 cat << EOF
- _______  _______  __   __  ___   __    _ 
+ _______  _______  __   __  ___   __    _
 |   _   ||       ||  | |  ||   | |  |  | |
 |  |_|  ||_     _||  | |  ||   | |   |_| |
 |       |  |   |  |  |_|  ||   | |       |
@@ -95,7 +95,7 @@ __atuin_install_linux(){
 
 	if [ "$OS" == "Arch" ] || [ "$OS" == "ManjaroLinux" ]; then
 		__atuin_install_arch
-    elif [ "$OS" == "Ubuntu" ] || [ "$OS" == "UbuntuWSL" ] || [ "$OS" == "Debian" ] || [ "$OS" == "Linuxmint" ] || [ "$OS" == "Parrot" ] || [ "$OS" == "Kali" ] || [ "$OS" == "Elementary" ]; then
+    elif [ "$OS" == "Ubuntu" ] || [ "$OS" == "UbuntuWSL" ] || [ "$OS" == "Debian" ] || [ "$OS" == "Linuxmint" ] || [ "$OS" == "Parrot" ] || [ "$OS" == "Kali" ] || [ "$OS" == "Elementary" ] || [ "$OS" == "Pop" ]; then
 		__atuin_install_ubuntu
 	else
 		# TODO: download a binary or smth
@@ -118,6 +118,18 @@ __atuin_install_mac(){
 
 }
 
+__atuin_install_termux(){
+	echo "Termux detected!"
+
+	if command -v pkg &> /dev/null; then
+		echo "Installing with pkg"
+		pkg install atuin
+	else
+		echo "Could not find pkg"
+		__atuin_install_unsupported
+	fi
+}
+
 __atuin_install_cargo(){
 	echo "Attempting install with cargo"
 
@@ -157,12 +169,13 @@ __atuin_install_unsupported(){
 
 # TODO: would be great to support others!
 case "$OSTYPE" in
-  linux*)   __atuin_install_linux ;;
-  darwin*)  __atuin_install_mac ;;
-  msys*)    __atuin_install_unsupported ;;
-  solaris*) __atuin_install_unsupported ;;
-  bsd*)     __atuin_install_unsupported ;;
-  *)        __atuin_install_unsupported ;;
+  linux-android*) __atuin_install_termux ;;
+  linux*)         __atuin_install_linux ;;
+  darwin*)        __atuin_install_mac ;;
+  msys*)          __atuin_install_unsupported ;;
+  solaris*)       __atuin_install_unsupported ;;
+  bsd*)           __atuin_install_unsupported ;;
+  *)              __atuin_install_unsupported ;;
 esac
 
 # TODO: Check which shell is in use
@@ -175,3 +188,30 @@ printf '\n[[ -f ~/.bash-preexec.sh ]] && source ~/.bash-preexec.sh\n' >> ~/.bash
 # Use of single quotes around $() is intentional here
 # shellcheck disable=SC2016
 echo 'eval "$(atuin init bash)"' >> ~/.bashrc
+
+cat << EOF
+
+
+
+ _______  __   __  _______  __    _  ___   _    __   __  _______  __   __ 
+|       ||  | |  ||   _   ||  |  | ||   | | |  |  | |  ||       ||  | |  |
+|_     _||  |_|  ||  |_|  ||   |_| ||   |_| |  |  |_|  ||   _   ||  | |  |
+  |   |  |       ||       ||       ||      _|  |       ||  | |  ||  |_|  |
+  |   |  |       ||       ||  _    ||     |_   |_     _||  |_|  ||       |
+  |   |  |   _   ||   _   || | |   ||    _  |    |   |  |       ||       |
+  |___|  |__| |__||__| |__||_|  |__||___| |_|    |___|  |_______||_______|
+
+
+
+Thanks for installing Atuin! I really hope you like it.
+
+If you have any issues, please open an issue on GitHub or visit our Discord (https://discord.gg/dPhv2B3x)!
+
+Otherwise, Atuin is a hobby project - if you find it valuable, you can help us out!
+
+- ⭐️ Give us a star on GitHub (https://github.com/ellie/atuin)
+- 🚀 Contribute! We would love more regular contributors (https://github.com/ellie/atuin)
+- 🤑 Sponsor me! If you value the project + want to help keep the hosted sync server free (https://github.com/sponsors/ellie)
+
+~ Ellie 🐢💖
+EOF
