@@ -1,26 +1,33 @@
 #![warn(clippy::pedantic, clippy::nursery)]
 #![allow(clippy::use_self, clippy::missing_const_for_fn)] // not 100% reliable
 
-use clap::{AppSettings, Parser};
+use clap::Parser;
 use eyre::Result;
 
-#[macro_use]
-extern crate log;
-
 use command::AtuinCmd;
 mod command;
 
 const VERSION: &str = env!("CARGO_PKG_VERSION");
 
+static HELP_TEMPLATE: &str = "\
+{before-help}{name} {version}
+{author}
+{about}
+
+{usage-heading}
+  {usage}
+
+{all-args}{after-help}";
+
 /// Magical shell history
 #[derive(Parser)]
-#[clap(
+#[command(
     author = "Ellie Huxtable <e@elm.sh>",
     version = VERSION,
-    global_setting(AppSettings::DeriveDisplayOrder),
+    help_template(HELP_TEMPLATE),
 )]
 struct Atuin {
-    #[clap(subcommand)]
+    #[command(subcommand)]
     atuin: AtuinCmd,
 }
 
